#!/bin/bash
set -u

# Usage: 
# Run with no args, or optionally a 'branch' arg with value of the branch
# of the Helix Installer to use (e.g. 'main' or 'dev').  If omitted, the
# branch is detected if possible, or else defaulted to 'main'.

# Bootstraps a new Linux server with requirements Helix Installer testing.

function msg () { echo -e "$*"; }
function bail () { msg "\\nError: ${1:-Unknown Error}\\n"; exit ${2:-1}; }

Branch=${1:-Unset}

if [[ "$Branch" == "Unset" ]]; then
   if [[ "$PWD" == *"/dev/"* ]]; then
      Branch="dev"
   elif [[ "$PWD" == *"/main/"* ]]; then
      Branch="main"
   else
      Branch="dev"
      msg "Warning: Helix Installer branch auto-detect failed. using $Branch."
   fi
fi

# Currently, RHEL/CentOS is supported, Ubuntu is not (yet) supported.
if [[ -r "/etc/redhat-release" ]]; then
   msg "Verified: Running on supported Red Hat or similar Linux OS."
elif [[ -r "/etc/lsb-release" ]]; then
   bail "Running on unsupported Ubuntu or similar Linux OS. Aborting."
else
   msg "Warning: Running on unknown OS. Hoping for the best."
fi

sudo yum install -y gcc gcc-c++ rsync zlib-devel openssl-devel
sudo useradd perforce
sudo mkdir -p /hxdepots/reset
sudo chown -R perforce:perforce /hxdepots/reset
cd /hxdepots/reset
curl -k -s -O https://swarm.workshop.perforce.com/downloads/guest/perforce_software/helix-installer/main/src/reset_sdp.sh

sudo chmod +x reset_sdp.sh

HelixInstallerVersion=$(grep '^Version=' reset_sdp.sh)
HelixInstallerVersion=${HelixInstallerVersion#declare }
msg "Installer Installer version: $HelixInstallerVersion"

msg "Calling Helix Installer, reset_sdp.sh."
sudo ./reset_sdp.sh > reset_sdp.log 2>&1
